==> mg_pso_gui-0.0.179-py3-none-any.whl: mgpsogui/gui/SetupTab/SetupTab.py <==


from . import StepView as sv
from . import StaticParameterView as spv
from . import CalibrationParametersView as cpv

import customtkinter

def create_tab(self, tab):
    
    tab.grid_columnconfigure(0, weight=1)
    tab.grid_columnconfigure(1, weight=8)
    tab.grid_rowconfigure(0, weight=1)
    
    self.paramtabview = customtkinter.CTkTabview(self, bg_color="transparent", fg_color="transparent")
    self.paramtabview.grid(row=0, column=0, padx=(0, 0), pady=(10, 10), sticky="nsew")
    
    tab1 = "Static"
    tab2 = "Calibration"
    self.paramtabview.add(tab1)
    self.paramtabview.add(tab2)
    
    self.static_param_frame = spv.StaticParameterView(self.paramtabview.tab(tab1), label_text="Static Parameters", option_manager=self.option_manager)
    self.static_param_frame.grid(row=0, column=0, padx=(10, 10), pady=(10, 0), sticky="nsew")
    self.static_param_frame.grid_columnconfigure(0, weight=1)
    self.static_param_frame.grid_rowconfigure(0, weight=1)
    
    self.calib_param_frame = cpv.CalibrationParametersView(self.paramtabview.tab(tab2), label_text="Calibration Parameters", option_manager=self.option_manager)
    self.calib_param_frame.grid(row=0, column=0, padx=(10, 10), pady=(10, 0), sticky="nsew")
    self.calib_param_frame.grid_columnconfigure(0, weight=1)
    self.calib_param_frame.grid_rowconfigure(0, weight=1)
    
    self.steps_frame = sv.StepView(tab, label_text="Group Editor", option_manager=self.option_manager)
    self.steps_frame.grid(row=0, column=1, padx=(10, 10), pady=(10, 0), sticky="nsew")
    self.steps_frame.grid_columnconfigure(0, weight=1)
    self.steps_frame.grid_rowconfigure(0, weight=1)

==> mg_pso_gui-0.0.181-py3-none-any.whl: mgpsogui/gui/SetupTab/SetupTab.py <==


from . import StepView as sv
from . import StaticParameterView as spv
from . import CalibrationParametersView as cpv

import customtkinter

def create_tab(self, tab):
    
    tab.grid_columnconfigure(0, weight=1)
    tab.grid_columnconfigure(1, weight=8)
    tab.grid_rowconfigure(0, weight=1)
    
    self.paramtabview = customtkinter.CTkTabview(tab, bg_color="transparent", fg_color="transparent")
    self.paramtabview.grid(row=0, column=0, padx=(0, 0), pady=(10, 10), sticky="nsew")
    
    tab1 = "Static"
    tab2 = "Calibration"
    self.paramtabview.add(tab1)
    self.paramtabview.add(tab2)
    
    self.paramtabview.tab(tab1).grid_columnconfigure(0, weight=1)
    self.paramtabview.tab(tab1).grid_rowconfigure(0, weight=1)
    
    self.paramtabview.tab(tab2).grid_columnconfigure(0, weight=1)
    self.paramtabview.tab(tab2).grid_rowconfigure(0, weight=1)
    
    self.static_param_frame = spv.StaticParameterView(self.paramtabview.tab(tab1), label_text="Static Parameters", option_manager=self.option_manager)
    self.static_param_frame.grid(row=0, column=0, padx=(10, 10), pady=(10, 0), sticky="nsew")
    self.static_param_frame.grid_columnconfigure(0, weight=1)
    self.static_param_frame.grid_rowconfigure(0, weight=1)
    
    self.calib_param_frame = cpv.CalibrationParametersView(self.paramtabview.tab(tab2), label_text="Calibration Parameters", option_manager=self.option_manager)
    self.calib_param_frame.grid(row=0, column=0, padx=(10, 10), pady=(10, 0), sticky="nsew")
    self.calib_param_frame.grid_columnconfigure(0, weight=1)
    self.calib_param_frame.grid_rowconfigure(0, weight=1)
    
    self.steps_frame = sv.StepView(tab, label_text="Group Editor", option_manager=self.option_manager)
    self.steps_frame.grid(row=0, column=1, padx=(10, 10), pady=(10, 0), sticky="nsew")
    self.steps_frame.grid_columnconfigure(0, weight=1)
    self.steps_frame.grid_rowconfigure(0, weight=1)
